GEM character set - Wikipedia

# GEM character set

From Wikipedia, the free encyclopedia
Jump to navigation Jump to search

The GEM character set is the character set of Digital Research's graphical user interface GEM on Intel platforms. It is based on code page 437, the original character set of the IBM PC, and like that set includes ASCII codes 32–126, extended codes for accented letters (diacritics), and other symbols. It differs from code page 437 in using other dingbats at code points 0–31, in exchanging the box-drawing characters 176–223 for international characters and other symbols, and exchanging code point 236 with the symbol for line integral. However, GEM is more similar to code page 865 because the codepoints of Ø and ø match the codepoints in that codepage.

The Motorola-based GEM adaptation for the Atari ST family of computers utilized the similar Atari ST character set. It has swapped ¢ and ø and has also swapped ¥ and Ø (to match code page 437 more). It also has the sharp S (sharp s) at code point 158, reversed not sign (⌐) at code point 169 (as in code page 437), not sign (¬) at code point 170 (as in code page 437), ½ at code point 171 (as in code page 437), ¼ at code point 172 (as in code page 437), ¨ (diaeresis) at code point 184, ´ (acute) at code point 185, ĳ at code point 192, Ĳ at code point 193, Hebrew characters at code points 194-220, section sign (§) at code point 221, logical and at code point 222, infinity sign at code point 223, bullet (•) at codepoint 249, cubed sign (superscript three) at code point 254, the macron at code point 255, ATARI-specific characters at codepoints 5, 6, 7, 14, 15, 28, 29, 30, and 31, LED 0-9 at codepoints 16-25, and ə (Schwa) at codepoint 26. Codepoints 12, 13, and 27 are mapped to the C0 controls.

A slight adaptation for Ventura Publisher is the similar Ventura International character set, it has code points 0-31, 127, and 218-255 empty, and has swapped ¢ and ø and has also swapped ¥ and Ø (to match code page 437 more).

In contrast to this, the GEM-derived file manager ViewMAX, which shipped with some versions of DR DOS as a DOSSHELL replacement, does not use the GEM character set, but loads its display fonts from DOS .CPI files[1][2][3][4][5][6] depending on the system's current code page.

## Character set[edit]

The following table shows the GEM character set. Each character is shown with a potential Unicode equivalent, although some codes do not have a unique, single Unicode equivalent; the correct choice may depend upon context. Note that code point 20 (1416) has an unfilled paragraph sign, and code point 188 (BC16) has a filled paragraph sign.

GEM character set[7][8][3][9]
| _0 | _1 | _2 | _3 | _4 | _5 | _6 | _7 | _8 | _9 | _A | _B | _C | _D | _E | _F
--- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | ---
0_ 0 | NUL 0000 | ⇧ 21E7 | ⇩ 21E9 | ⇨ 21E8 | ⇦ 21E6 | ◼ 25FC | 🗗 1F5D7 | ◆ 25C6 | ✓ 2713 | 🕒︎ 1F552 | 🔔︎ 1F514 | ♪ 266A | ▴ 25B4 | ▾ 25BE | ▸ 25B8 | ◂ 25C2
1_ 16 | ► 25BA | ◄ 25C4 | ⧓ 29D3 | ▂ 2582 | ¶ 00B6 | § 00A7 | ↕ 2195 | ↨ 21A8 | ↑ 2191 | ↓ 2193 | → 2192 | ← 2190 | ∟ 221F | ↔ 2194 | ▲ 25B2 | ▼ 25BC
2_ 32 | SP 0020 | ! 0021 | " 0022 | # 0023 | $ 0024 | % 0025 | & 0026 | ' 0027 | ( 0028 | ) 0029 | * 002A | + 002B | , 002C | - 002D | . 002E | / 002F
3_ 48 | 0 0030 | 1 0031 | 2 0032 | 3 0033 | 4 0034 | 5 0035 | 6 0036 | 7 0037 | 8 0038 | 9 0039 | : 003A | ; 003B | < 003C | = 003D | > 003E | ? 003F
4_ 64 | @ 0040 | A 0041 | B 0042 | C 0043 | D 0044 | E 0045 | F 0046 | G 0047 | H 0048 | I 0049 | J 004A | K 004B | L 004C | M 004D | N 004E | O 004F
5_ 80 | P 0050 | Q 0051 | R 0052 | S 0053 | T 0054 | U 0055 | V 0056 | W 0057 | X 0058 | Y 0059 | Z 005A | [ 005B | \ 005C | ] 005D | ^ 005E | _ 005F
6_ 96 | ` 0060 | a 0061 | b 0062 | c 0063 | d 0064 | e 0065 | f 0066 | g 0067 | h 0068 | i 0069 | j 006A | k 006B | l 006C | m 006D | n 006E | o 006F
7_ 112 | p 0070 | q 0071 | r 0072 | s 0073 | t 0074 | u 0075 | v 0076 | w 0077 | x 0078 | y 0079 | z 007A | { 007B | | 007C | } 007D | ~ 007E | ⌂ 2302
8_ 128 | Ç 00C7 | ü 00FC | é 00E9 | â 00E2 | ä 00E4 | à 00E0 | å 00E5 | ç 00E7 | ê 00EA | ë 00EB | è 00E8 | ï 00EF | î 00EE | ì 00EC | Ä 00C4 | Å 00C5
9_ 144 | É 00C9 | æ 00E6 | Æ 00C6 | ô 00F4 | ö 00F6 | ò 00F2 | û 00FB | ù 00F9 | ÿ 00FF | Ö 00D6 | Ü 00DC | ø 00F8 | £ 00A3 | Ø 00D8 | ¤ 00A4 | ƒ 0192
A_ 160 | á 00E1 | í 00ED | ó 00F3 | ú 00FA | ñ 00F1 | Ñ 00D1 | ª 00AA | º 00BA | ¿ 00BF | “ 201C | ” 201D | ‹ 2039 | › 203A | ¡ 00A1 | « 00AB | » 00BB
B_ 176 | ã 00E3 | õ 00F5 | ¥ 00A5 | ¢ 00A2 | œ 0153 | Œ 0152 | À 00C0 | Ã 00C3 | Õ 00D5 | § 00A7 | ‡ 2021 | † 2020 | ¶ 00B6 | © 00A9 | ® 00AE | ™ 2122
C_ 192 | „ 201E | … 2026 | ‰ 2030 | • 2022 | – 2013 | — 2014 | ° 00B0 | Á 00C1 | Â 00C2 | È 00C8 | Ê 00CA | Ë 00CB | Ì 00CC | Í 00CD | Î 00CE | Ï 00CF
D_ 208 | Ò 00D2 | Ó 00D3 | Ô 00D4 | Š 0160 | š 0161 | Ù 00D9 | Ú 00DA | Û 00DB | Ÿ 0178 | ß 00DF |  |  |  |  |  |
E_ 224 | α 03B1 | β 03B2 | Γ 0393 | π 03C0 | Σ 03A3 | σ 03C3 | µ 00B5 | τ 03C4 | Φ 03A6 | Θ 0398 | Ω 03A9 | δ 03B4 | ∮ 222E | ɸ 0278 | ∈ 2208 | ∩ 2229
F_ 240 | ≡ 2261 | ± 00B1 | ≥ 2265 | ≤ 2264 | ⌠ 2320 | ⌡ 2321 | ÷ 00F7 | ≈ 2248 | ° 00B0 | ∙ 2219 | · 00B7 | √ 221A | ⁿ 207F | ² 00B2 | ■ 25A0 | ∅ 2205
| _0 | _1 | _2 | _3 | _4 | _5 | _6 | _7 | _8 | _9 | _A | _B | _C | _D | _E | _F

Letter Number Punctuation Symbol Other Undefined Different than code page 437

## See also[edit]

- Atari ST character set
- Western Latin character sets (computing)
- Alt codes
- Bitstream International Character Set
- Ventura International Character Set

## References[edit]

1. ^
   Paul, Matthias R. (2001-06-10) [1995]. "Format description of DOS, OS/2, and Windows NT .CPI, and Linux .CP files" (CPI.LST file) (1.30 ed.). Archived from the original on 2016-04-20. Retrieved 2016-08-20.
2. ^ Elliott, John C. (2006-10-14). "CPI file format". Seasip.info. Archived from the original on 2016-09-22. Retrieved 2016-09-22.
3. ^ a b Elliott, John C. (2006-09-03). "Codepage-related software". Seasip.info. Archived from the original on 2016-11-08. Retrieved 2016-11-09.
4. ^ Brouwer, Andries Evert (2001-02-10). "CPI fonts". 0.2. Archived from the original on 2016-09-22. Retrieved 2016-09-22.
5. ^ Haralambous, Yannis (September 2007). Fonts & Encodings. Translated by Horne, P. Scott (1 ed.). Sebastopol, California, USA: O'Reilly Media, Inc. pp. 601–602, 611. ISBN 978-0-596-10242-5.
6. ^ MS-DOS Programmer's Reference. Microsoft Press. 1991. ISBN 1-55615-329-5.
7. ^ "WordPlus GEM character set". Archived from the original on 2017-01-23. Retrieved 2017-01-23.
8. ^ Lineback, Nathan. "GEM 3.11 Screen Shots". Toastytech.com. Archived from the original on 2019-11-18. Retrieved 2016-08-01.
9. ^ Elliott, John C. (2006-09-04). "Fonts for Intel GEM - System Fonts". Seasip.info. Archived from the original on 2017-02-06. Retrieved 2016-09-22.

Retrieved from "https://en.wikipedia.org/w/index.php?title=GEM_character_set&oldid=1007071903"
Categories:

- Character sets
- Computer-related introductions in 1985